@@ -1,6 +1,4 @@
 /*
- *  Copyright (C) 2004-2017 Christos Tsantilas
- *
  *  This program is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public
  *  License as published by the Free Software Foundation; either
@@ -24,13 +22,18 @@
 #include "simple_api.h"
 #include "debug.h"
 
-#include <assert.h>
 #ifdef HAVE_ZLIB
 #include <zlib.h>
 #endif
 #ifdef HAVE_BZLIB
 #include <bzlib.h>
 #endif
+#ifdef HAVE_BROTLI
+#include "brotli/decode.h"
+#include "brotli/encode.h"
+#include "brotli/types.h"
+#include "brotli/port.h"
+#endif
 
 
 unsigned char base64_table[] = {
@@ -64,25 +67,25 @@ int ci_base64_decode(const char *encoded, char *decoded, int len)
     str = (unsigned char *)encoded;
     result = (unsigned char *)decoded;
 
-    for (i=len; i>3; i-=3) {
+    for (i = len; i > 3; i -= 3) {
 
         /*if one of the last 4 bytes going to be proccessed is not valid just
           stops processing. This "if" cover the '\0' string termination character
-          of str (because base64_table[0]=255)
+          of str (because base64_table[0] = 255)
          */
         if (base64_table[*str]>63 || base64_table[*(str+1)] > 63 ||
                 base64_table[*(str+2)] > 63 ||base64_table[*(str+3)] > 63)
             break;
 
         /*6 bits from the first + 2 last bits from second*/
-        *(result++)=(base64_table[*str] << 2) | (base64_table[*(str+1)] >>4);
+        *(result++) = (base64_table[*str] << 2) | (base64_table[*(str+1)] >>4);
         /*last 4 bits from second + first 4 bits from third*/
-        *(result++)=(base64_table[*(str+1)] << 4) | (base64_table[*(str+2)] >>2);
+        *(result++) = (base64_table[*(str+1)] << 4) | (base64_table[*(str+2)] >>2);
         /*last 2 bits from third + 6 bits from forth */
-        *(result++)=(base64_table[*(str+2)] << 6) | (base64_table[*(str+3)]);
+        *(result++) = (base64_table[*(str+2)] << 6) | (base64_table[*(str+3)]);
         str += 4;
     }
-    *result='\0';
+    *result = '\0';
     return len-i;
 }
 
@@ -91,9 +94,9 @@ char *ci_base64_decode_dup(const char *encoded)
 {
     int len;
     char *result;
-    len=strlen(encoded);
-    len=((len+3)/4)*3+1;
-    if (!(result=malloc(len*sizeof(char))))
+    len = strlen(encoded);
+    len = ((len+3)/4)*3+1;
+    if (!(result = malloc(len*sizeof(char))))
         return NULL;
 
     ci_base64_decode(encoded,result,len);
@@ -117,7 +120,7 @@ int ci_base64_encode(const unsigned char *data, size_t len, char *out, size_t ou
                              "abcdefghijklmnopqrstuvwxyz"\
                              "0123456789"\
                              "+/";
-    for (i = 0, k=0; i < (len - 3) && k < (outlen - 4); i+=3) {
+    for (i = 0, k = 0; i < (len - 3) && k < (outlen - 4); i += 3) {
         dobase64(out, data[i], data[i + 1], data[i + 2]);
     }
     /*if the outlen is enough big*/
@@ -198,7 +201,7 @@ static const char *uncompress_errors[] = {
     "uncompress: Compression Bomb"
 };
 
-const char *ci_inflate_error(int err)
+const char *ci_decompress_error(int err)
 {
     ci_debug_printf (7, "Inflate error %d\n", err);
     if (err < CI_UNCOMP_ERR_NONE && err >= CI_UNCOMP_ERR_BOMB)
@@ -206,6 +209,35 @@ const char *ci_inflate_error(int err)
     return "No Error";
 }
 
+const char *ci_inflate_error(int err)
+{
+    return ci_decompress_error(err);
+}
+
+int ci_encoding_method(const char *content_encoding)
+{
+    if (!content_encoding)
+        return CI_ENCODE_NONE;
+
+    if (strcasestr(content_encoding, "gzip") != NULL) {
+        return CI_ENCODE_GZIP;
+    }
+
+    if (strcasestr(content_encoding, "deflate") != NULL) {
+        return CI_ENCODE_DEFLATE;
+    }
+
+    if (strcasestr(content_encoding, "br") != NULL) {
+        return CI_ENCODE_BROTLI;
+    }
+
+    if (strcasestr(content_encoding, "bzip2") != NULL) {
+        return CI_ENCODE_BZIP2;
+    }
+
+    return CI_ENCODE_UNKNOWN;
+}
+
 static int write_membuf_func(void *obj, const char *buf, size_t len)
 {
     return ci_membuf_write((ci_membuf_t *)obj, buf, len, 0);
@@ -239,6 +271,212 @@ static int write_once_to_outbuf(void *obj, const char *buf, size_t len)
     return 0;
 }
 
+
+/*return CI_INFLATE_ERRORS
+ */
+int ci_decompress_to_membuf(int encoding_format, const char *inbuf, size_t inlen, ci_membuf_t *outbuf, ci_off_t max_size)
+{
+    switch (encoding_format) {
+    case CI_ENCODE_NONE:
+        return CI_UNCOMP_OK;
+        break;
+#ifdef HAVE_ZLIB
+    case CI_ENCODE_GZIP:
+    case CI_ENCODE_DEFLATE:
+        return ci_inflate_to_membuf(inbuf, inlen, outbuf, max_size);
+        break;
+#endif
+#ifdef HAVE_BZLIB
+    case CI_ENCODE_BZIP2:
+        return ci_bzunzip_to_membuf(inbuf, inlen, outbuf, max_size);
+        break;
+#endif
+#ifdef HAVE_BROTLI
+    case CI_ENCODE_BROTLI:
+        return ci_brinflate_to_membuf(inbuf, inlen, outbuf, max_size);
+        break;
+#endif
+    case CI_ENCODE_UNKNOWN:
+    default:
+        return CI_UNCOMP_ERR_ERROR;
+        break;
+    }
+}
+
+/*return CI_INFLATE_ERRORS
+ */
+int ci_decompress_to_simple_file(int encoding_format, const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size)
+{
+    switch (encoding_format) {
+    case CI_ENCODE_NONE:
+        return CI_UNCOMP_OK;
+        break;
+#ifdef HAVE_ZLIB
+    case CI_ENCODE_GZIP:
+    case CI_ENCODE_DEFLATE:
+        return ci_inflate_to_simple_file(inbuf, inlen, outbuf, max_size);
+        break;
+#endif
+#ifdef HAVE_BZLIB
+    case CI_ENCODE_BZIP2:
+        return ci_bzunzip_to_simple_file(inbuf, inlen, outbuf, max_size);
+        break;
+#endif
+#ifdef HAVE_BROTLI
+    case CI_ENCODE_BROTLI:
+        return ci_brinflate_to_simple_file(inbuf, inlen, outbuf, max_size);
+        break;
+#endif
+    case CI_ENCODE_UNKNOWN:
+    default:
+        return CI_UNCOMP_ERR_ERROR;
+        break;
+    }
+}
+
+#ifdef HAVE_BROTLI
+#define DEFAULT_LGWIN    22
+#define DEFAULT_QUALITY  11
+#define kFileBufferSize 16384
+
+int Br_Decompress(BrotliDecoderState* s, const char *buf, int inlen, void *outbuf, char *(*get_outbuf)(void *obj, unsigned int *len), int (*writefunc)(void *obj, const char *buf, size_t len), ci_off_t max_size)
+{
+    size_t available_in = 0;
+    const uint8_t* next_in = NULL;
+    size_t available_out = kFileBufferSize;
+    uint8_t* next_out;
+    unsigned have, written, can_write;
+    long long outsize;
+    size_t total_out = 0;
+    BrotliDecoderResult result = BROTLI_DECODER_RESULT_NEEDS_MORE_INPUT;
+    uint8_t *out, OUT[kFileBufferSize];
+
+    ci_debug_printf(4, "data-compression: brotli decompress called size: %d\n",
+                    inlen);
+
+    next_in = (uint8_t *)buf;
+    available_in = inlen;
+    outsize = 0;
+    for (;;) {
+        if (get_outbuf) {
+            unsigned int outbuf_size;
+            out = (uint8_t *)get_outbuf(outbuf, &outbuf_size);
+            if (!out)
+                return CI_UNCOMP_ERR_OUTPUT;
+            available_out = outbuf_size;
+        } else {
+            out = OUT;
+            available_out = kFileBufferSize;
+        }
+        next_out = out;
+        result = BrotliDecoderDecompressStream(s,
+                                               &available_in, &next_in,
+                                               &available_out,
+                                               &next_out, &total_out);
+        have = kFileBufferSize - available_out;
+        can_write = (max_size > 0 && (max_size - outsize) < have) ? (max_size - outsize) : have;
+        if ((written = writefunc(outbuf, (char *)out, can_write)) != can_write) {
+            ci_debug_printf(2, "data-compression: brotli decoded data not written to output (%u/%u)\n", written, have);
+            return CI_UNCOMP_ERR_OUTPUT;
+        }
+        outsize += written;
+        if (written < have) {
+            if ((outsize/inlen) > 100) {
+                ci_debug_printf(1, "data-compression: brotli Compression ratio UncompSize/CompSize = %"
+                                PRINTF_OFF_T "/%" PRINTF_OFF_T " = %" PRINTF_OFF_T
+                                "! Is it a zip bomb? aborting!\n",
+                                (CAST_OFF_T)outsize,
+                                (CAST_OFF_T)inlen,
+                                (CAST_OFF_T)(outsize/inlen));
+                return CI_UNCOMP_ERR_BOMB;
+            } else {
+                ci_debug_printf(4, "data-compression: brotli Object is bigger than max allowed file\n");
+                return CI_UNCOMP_ERR_NONE;
+            }
+        }
+        switch (result) {
+        case BROTLI_DECODER_RESULT_NEEDS_MORE_INPUT:
+            if (available_in == 0) {
+                ci_debug_printf(2, "data-compression: brotli needs more data, but there are not available\n");
+                return CI_UNCOMP_ERR_CORRUPT;
+            }
+            ci_debug_printf(4, "data-compression: brotli needs more input\n");
+            break;
+        case BROTLI_DECODER_RESULT_NEEDS_MORE_OUTPUT:
+            /* Nothing to do - output is already written. */
+            break;
+        case BROTLI_DECODER_RESULT_SUCCESS:
+            if (available_in != 0) {
+                ci_debug_printf(4, "data-compression: brotli finished but available_in != 0\n");
+                return CI_UNCOMP_ERR_CORRUPT;
+            }
+            ci_debug_printf(4, "data-compression: brotli total uncompressed size: %lld (%lld)\n",
+                            outsize, (long long)total_out);
+            return CI_UNCOMP_OK;
+        default:
+            ci_debug_printf(2, "data-compression: brotli corrupt input\n");
+            return CI_UNCOMP_ERR_CORRUPT;
+        }
+
+    }
+}
+
+int ci_mem_brinflate(const char *inbuf, int inlen, void *outbuf, char *(*get_outbuf)(void *obj, unsigned int *len), int (*writefunc)(void *obj, const char *buf, size_t len), ci_off_t max_size)
+{
+    BROTLI_BOOL ccode = BROTLI_TRUE;
+    BrotliDecoderState *s;
+
+    s = BrotliDecoderCreateInstance(NULL, NULL, NULL);
+    if (!s) {
+        ci_debug_printf(4, "data-compression: brotli out of memory\n");
+        return -1;
+    }
+    ccode = Br_Decompress(s, inbuf, inlen, outbuf, get_outbuf, writefunc, max_size);
+    BrotliDecoderDestroyInstance(s);
+    return ccode;
+}
+
+int ci_brinflate_to_membuf(const char *inbuf, size_t inlen, ci_membuf_t *outbuf, ci_off_t max_size)
+{
+    int ret = ci_mem_brinflate(inbuf, inlen, outbuf, NULL, write_membuf_func, max_size);
+    ci_membuf_write(outbuf, "", 0, 1);
+    return ret;
+}
+
+int ci_brinflate_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size)
+{
+    int ret = ci_mem_brinflate(inbuf, inlen, outbuf, NULL, write_simple_file_func, max_size);
+    ci_simple_file_write(outbuf, "", 0, 1);
+    return ret;
+}
+
+static int brotli_inflate_step(const char *buf, int len, char *unzipped_buf, int *unzipped_buf_len)
+{
+    struct unzipBuf ub;
+    ub.buf = unzipped_buf;
+    ub.buf_size = *unzipped_buf_len;
+    int ret = ci_mem_brinflate(buf, len,  &ub, get_buf_outbuf, write_once_to_outbuf, len);
+    ci_debug_printf(5, "brotli_inflate_step: retcode %d, unzipped data: %d\n", ret, (int)ub.out_len);
+    if (ub.out_len >= 0) {
+        *unzipped_buf_len = ub.out_len;
+        return CI_OK;
+    }
+    return CI_ERROR;
+}
+#else
+int ci_brinflate_to_membuf(const char *inbuf, size_t inlen, ci_membuf_t *outbuf, ci_off_t max_size)
+{
+    ci_debug_printf(1, "brotlidecode is not supported.\n");
+    return CI_UNCOMP_ERR_NONE;
+}
+
+int ci_brinflate_to_simple_file(const char *inbuf, size_t inlen, struct ci_simple_file *outbuf, ci_off_t max_size)
+{
+    ci_debug_printf(1, "brotlidecode is not supported.\n");
+    return CI_UNCOMP_ERR_NONE;
+}
+#endif
+
 #ifdef HAVE_ZLIB
 #define ZIP_HEAD_CRC     0x02   /* bit 1 set: header CRC present */
 #define ZIP_EXTRA_FIELD  0x04   /* bit 2 set: extra field present */
@@ -255,7 +493,6 @@ static void free_a_buffer(void *op, void *ptr)
     ci_buffer_free(ptr);
 }
 
-
 /*return CI_INFLATE_ERRORS
  */
 int ci_mem_inflate(const char *inbuf, size_t inlen, void *out_obj, char *(*get_outbuf)(void *obj, unsigned int *len), int (*writefunc)(void *obj, const char *buf, size_t len), ci_off_t max_size)
@@ -297,7 +534,10 @@ do_mem_inflate_retry:
             strm.next_out = out = OUT;
         }
         ret = inflate(&strm, Z_NO_FLUSH);
-        assert(ret != Z_STREAM_ERROR);  /* state not clobbered */
+        if (ret == Z_STREAM_ERROR) {
+            //probably means memory overrun/overwrite etc
+            ci_debug_printf(1, "Zlib/Z_STREAM_ERROR, corrupted input data to inflate?\n");
+        }
         switch (ret) {
         case Z_NEED_DICT:
         case Z_DATA_ERROR:
@@ -311,6 +551,7 @@ do_mem_inflate_retry:
                 }
                 /*else let fail ...*/
             }
+        case Z_STREAM_ERROR:
         case Z_MEM_ERROR:
             inflateEnd(&strm);
             return CI_UNCOMP_ERR_CORRUPT;
@@ -335,10 +576,15 @@ do_mem_inflate_retry:
         }
     } while (strm.avail_out == 0);
 
-    /* done when inflate() says it's done */
-    assert(ret == Z_STREAM_END);
     /* clean up and return */
     inflateEnd(&strm);
+    /*
+      ret == Z_STREAM_END means that the decompression was succesfull
+      else the output data are corrupted or not produced at all.
+      Example case is when the input data are not enough to produce
+      a single byte of decompressed data, so the inflate() return Z_OK
+      (eg during preview request with few preview data)
+     */
     return ret == Z_STREAM_END ? CI_UNCOMP_OK : CI_UNCOMP_ERR_CORRUPT;
 }
 
@@ -522,8 +768,13 @@ int ci_uncompress_preview(int compress_method, const char *buf, int len, char *u
         return  bzlib_uncompress_step(buf, len, unzipped_buf, unzipped_buf_len);
     else
 #endif
+#ifdef HAVE_BROTLI
+        if (compress_method == CI_ENCODE_BROTLI)
+            return  brotli_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
+        else
+#endif
 #ifdef HAVE_ZLIB
-        return zlib_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
+            return zlib_inflate_step(buf, len, unzipped_buf, unzipped_buf_len);
 #endif
     return CI_ERROR;
 }
