@@ -409,9 +409,9 @@ static const char text_chars[256] = {
 
 
 /*
-ASCII if res<=1
-ISO if res<=3
-EXTEND if res<=7
+ASCII if res <= 1
+ISO if res <= 3
+EXTEND if res <= 7
 */
 
 int check_ascii(unsigned char *buf, int buflen)
@@ -499,7 +499,7 @@ int check_unicode(unsigned char *buf, int buflen)
     if (ret < 0 && i == 0)
         ret = 0;              /*Not enough data to check */
 
-    if (ret)                   /*Even if the last char is unknown ret!=0 mean is utf */
+    if (ret)                   /*Even if the last char is unknown ret != 0 mean is utf */
         return CI_UTF_DATA;   /*... but what about if buflen is about 2 or 3 bytes long ? */
 
     /*check for utf16 .... */
@@ -567,16 +567,8 @@ int extend_object_type(struct ci_magics_db *db, ci_headers_list_t *headers, cons
     if (headers) {
         content_encoding = ci_headers_value(headers, "Content-Encoding");
         if (content_encoding) {
-            ci_debug_printf(8, "Content-Encoding :%s\n", content_encoding);
-            /*the following must be faster in the feature...... */
-            if (strcasestr(content_encoding, "gzip") != NULL) {
-                *iscompressed = CI_ENCODE_GZIP;
-            } else if (strcasestr(content_encoding, "deflate") != NULL) {
-                *iscompressed = CI_ENCODE_DEFLATE;
-            } else if (strcasestr(content_encoding, "bzip2") != NULL) {
-                *iscompressed = CI_ENCODE_BZIP2;
-            } else
-                *iscompressed = CI_ENCODE_UNKNOWN;
+            ci_debug_printf(8, "Content-Encoding: %s\n", content_encoding);
+            *iscompressed = ci_encoding_method(content_encoding);
 
             /*
               Bzip2 comressed data are not usefull on preview data, because ci_uncompress_preview
@@ -587,7 +579,8 @@ int extend_object_type(struct ci_magics_db *db, ci_headers_list_t *headers, cons
 #if 0
                     || *iscompressed == CI_ENCODE_BZIP2
 #endif
-                    || *iscompressed == CI_ENCODE_DEFLATE) {
+                    || *iscompressed == CI_ENCODE_DEFLATE
+                    || *iscompressed == CI_ENCODE_BROTLI) {
                 unzipped_buf = ci_buffer_alloc(len); /*Will I implement memory pools? when????? */
                 unzipped_buf_len = len;
                 if (ci_uncompress_preview
@@ -613,7 +606,7 @@ int extend_object_type(struct ci_magics_db *db, ci_headers_list_t *headers, cons
 
     file_type = ci_filetype(db, checkbuf, len);
 
-    ci_debug_printf(7, "File type returned :%s,%s\n",
+    ci_debug_printf(7, "File type returned: %s,%s\n",
                     ci_data_type_name(db, file_type),
                     ci_data_type_descr(db, file_type));
     /*The following until we have an internal html recognizer ..... */
@@ -636,7 +629,7 @@ int extend_object_type(struct ci_magics_db *db, ci_headers_list_t *headers, cons
 #endif
 
 
-    ci_debug_printf(7, "The file type now is :%s,%s\n",
+    ci_debug_printf(7, "The file type now is: %s,%s\n",
                     ci_data_type_name(db, file_type),
                     ci_data_type_descr(db, file_type));
 #ifdef HAVE_ZLIB
@@ -646,7 +639,7 @@ int extend_object_type(struct ci_magics_db *db, ci_headers_list_t *headers, cons
     return file_type;
 }
 
-int ci_extend_filetype(struct ci_magics_db *db, ci_request_t * req, const char *buf,
+int ci_extend_filetype(struct ci_magics_db *db, ci_request_t *req, const char *buf,
                        int len, int *iscompressed)
 {
     ci_headers_list_t *heads;
