@@ -121,6 +121,7 @@ int icap_port_tls_option(const char *opt, ci_port_t *conf, const char *config_di
       TODO: Check for valid options!
      */
     if (strncmp(opt, "tls-method=", 11) == 0) {
+        ci_debug_printf(1, "WARNING: 'tls-method=' option is deprecated, use SSL_OP_NO_TLS* options to disable one or more TLS protocol versions\n");
         conf->tls_method = strdup(opt + 11);
     } else if (strncmp(opt, "cert=", 5) == 0) {
         conf->tls_server_cert = path_dup(opt + 5, config_dir);
@@ -129,9 +130,9 @@ int icap_port_tls_option(const char *opt, ci_port_t *conf, const char *config_di
     } else if (strncmp(opt, "client_ca=", 10) == 0) {
         conf->tls_client_ca_certs = path_dup(opt + 10, config_dir);
     } else if (strncmp(opt, "cafile=", 7) == 0) {
-        conf->tls_cafile = path_dup(opt + 10, config_dir);
+        conf->tls_cafile = path_dup(opt + 7, config_dir);
     } else if (strncmp(opt, "capath=", 7) == 0) {
-        conf->tls_capath = path_dup(opt + 10, config_dir);
+        conf->tls_capath = path_dup(opt + 7, config_dir);
     } else if (strncmp(opt, "ciphers=", 8) == 0) {
         conf->tls_ciphers = strdup(opt + 8);
     } else if (strncmp(opt, "tls-options=", 12) == 0) {
@@ -167,7 +168,7 @@ static int set_linger(int sock, int secs_to_linger)
 static int openssl_verify_cert_cb (int ok, X509_STORE_CTX *ctx)
 {
     if (ok == 0) {
-        ci_debug_printf(1, "Peer cert verification failed: %s\n", X509_verify_cert_error_string(ctx->error));
+        ci_debug_printf(1, "Peer cert verification failed: %s\n", X509_verify_cert_error_string(X509_STORE_CTX_get_error(ctx)));
         return 0;
     }
     return 1;
@@ -186,7 +187,7 @@ static int openssl_cert_passphrase_cb(char *buf, int size, int rwflag, void *u)
     snprintf(script, sizeof(script), "%s %s %d", TLS_PASSPHRASE_SCRIPT, port->address ? port->address : "*", port->port);
     script[sizeof(script) - 1] = '\0';
 
-    FILE *f=popen(script, "r");
+    FILE *f = popen(script, "r");
     int bytes = fread(buf, 1, size, f);
     fclose(f);
 
@@ -229,11 +230,6 @@ static const SSL_METHOD* get_tls_method(const char* method_str, int b_for_server
         return (b_for_server) ? SSLv3_server_method() : SSLv3_client_method();
     }
 #endif
-#ifndef OPENSSL_NO_SSL2
-    else if ( 0 == strcmp(method_str, "SSLv2")) {
-        return (b_for_server) ? SSLv2_server_method() : SSLv2_client_method();
-    }
-#endif
 
     ci_debug_printf(1, "TLS/SSL method string \"%s\" not available.\n", method_str);
     return NULL;
@@ -243,7 +239,13 @@ static const SSL_METHOD* get_tls_method(const char* method_str, int b_for_server
 /*
  * SSL callback function for locking
  */
-static void openssl_locking_function(int mode, int n, const char* file, int line)
+#ifdef __GNUC__
+#define __LOCAL_UNUSED __attribute__ ((__unused__))
+#else
+#define __LOCAL_UNUSED
+#endif
+
+__LOCAL_UNUSED static void openssl_locking_function(int mode, int n, const char* file, int line)
 {
     if ( mode & CRYPTO_LOCK ) {
         ci_thread_mutex_lock(&g_openssl_mutexes[n]);
@@ -254,7 +256,7 @@ static void openssl_locking_function(int mode, int n, const char* file, int line
 /*
  * SSL callback function to identify the current thread
  */
-static unsigned long openssl_id_function()
+__LOCAL_UNUSED static unsigned long openssl_id_function()
 {
     return (unsigned long)ci_thread_self;
 }
@@ -439,6 +441,19 @@ int icap_init_server_tls(ci_port_t *port)
     return 1;
 }
 
+void icap_close_server_tls(ci_port_t *port)
+{
+    if (port->bio) {
+        BIO_free_all(port->bio);
+        port->bio = NULL;
+    }
+
+    if (port->tls_context) {
+        SSL_CTX_free(port->tls_context);
+        port->tls_context = NULL;
+    }
+}
+
 int ci_port_reconfigure_tls(ci_port_t *port)
 {
     assert(port->tls_enabled);
