@@ -978,7 +978,7 @@ static int get_send_body(ci_request_t * req, int parse_only)
         if (!req->data_locked && req->remain_send_block_bytes == 0) {
             if (update_send_status(req) == CI_ERROR)
                 return CI_ERROR;
-            // if(update_send_status==CI_EOF)/*earlier responce from icap server???...*/
+            // if(update_send_status == CI_EOF)/*earlier responce from icap server???...*/
         }
 
         /*Store lock status. If it is changed during module io, we need
@@ -1203,14 +1203,14 @@ static void options_responce(ci_request_t * req)
     ttl = srv_xdata->options_ttl;
     ci_service_data_read_unlock(srv_xdata);
 
-    ci_debug_printf(5, "Options responce:\n"
-                    " Preview :%d\n"
-                    " Allow 204:%s\n"
-                    " Allow 206:%s\n"
-                    " TransferPreview:\"%s\"\n"
-                    " TransferIgnore:%s\n"
-                    " TransferComplete:%s\n"
-                    " Max-Connections:%d\n",
+    ci_debug_printf(5, "Options response: \n"
+                    " Preview: %d\n"
+                    " Allow 204: %s\n"
+                    " Allow 206: %s\n"
+                    " TransferPreview: \"%s\"\n"
+                    " TransferIgnore: %s\n"
+                    " TransferComplete: %s\n"
+                    " Max-Connections: %d\n",
                     preview,(allow204?"yes":"no"),
                     (allow206?"yes":"no"),
                     srv_xdata->TransferPreview,
@@ -1525,7 +1525,7 @@ static int do_request(ci_request_t * req)
         if (res > EC_100 && req->request_header->bufused > 0)
             ec_responce(req, res);
         ci_debug_printf((req->request_header->bufused ? 5 : 11), "Error %d while parsing headers :(%d)\n",
-                        res ,req->request_header->bufused);
+                        res, req->request_header->bufused);
         return CI_ERROR;
     }
     assert(req->current_service_mod);
@@ -1650,7 +1650,7 @@ int process_request(ci_request_t * req)
     res = do_request(req);
 
     if (req->pstrblock_read_len) {
-        ci_debug_printf(5, "There are unparsed data od size %d: \"%s\"\n. Move to connection buffer\n", req->pstrblock_read_len, req->pstrblock_read);
+        ci_debug_printf(5, "There are unparsed data od size %d: \"%.*s\"\n. Move to connection buffer\n", req->pstrblock_read_len, (req->pstrblock_read_len < 64 ? req->pstrblock_read_len : 64), req->pstrblock_read);
     }
 
     if (res<0 && req->request_header->bufused == 0) /*Did not read anything*/
